"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing
import vdp.pipeline.v1beta.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ConnectorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConnectorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConnectorType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONNECTOR_TYPE_UNSPECIFIED: _ConnectorType.ValueType  # 0
    """Unspecified."""
    CONNECTOR_TYPE_SOURCE: _ConnectorType.ValueType  # 1
    """Source connector."""
    CONNECTOR_TYPE_DESTINATION: _ConnectorType.ValueType  # 2
    """Destination connector."""
    CONNECTOR_TYPE_AI: _ConnectorType.ValueType  # 3
    """AI connector."""
    CONNECTOR_TYPE_BLOCKCHAIN: _ConnectorType.ValueType  # 4
    """Blockchain connector."""
    CONNECTOR_TYPE_DATA: _ConnectorType.ValueType  # 5
    """Data connector."""
    CONNECTOR_TYPE_OPERATOR: _ConnectorType.ValueType  # 6
    """Operator connector."""

class ConnectorType(_ConnectorType, metaclass=_ConnectorTypeEnumTypeWrapper):
    """////////////////////////////////////////////////////////////////////////

    ConnectorType defines the connector type based on its task features.
    """

CONNECTOR_TYPE_UNSPECIFIED: ConnectorType.ValueType  # 0
"""Unspecified."""
CONNECTOR_TYPE_SOURCE: ConnectorType.ValueType  # 1
"""Source connector."""
CONNECTOR_TYPE_DESTINATION: ConnectorType.ValueType  # 2
"""Destination connector."""
CONNECTOR_TYPE_AI: ConnectorType.ValueType  # 3
"""AI connector."""
CONNECTOR_TYPE_BLOCKCHAIN: ConnectorType.ValueType  # 4
"""Blockchain connector."""
CONNECTOR_TYPE_DATA: ConnectorType.ValueType  # 5
"""Data connector."""
CONNECTOR_TYPE_OPERATOR: ConnectorType.ValueType  # 6
"""Operator connector."""
global___ConnectorType = ConnectorType

@typing_extensions.final
class ConnectorSpec(google.protobuf.message.Message):
    """//////////////////////////////////

    ConnectorSpec represents a specification data model.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_SPECIFICATION_FIELD_NUMBER: builtins.int
    COMPONENT_SPECIFICATION_FIELD_NUMBER: builtins.int
    OPENAPI_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_specification(self) -> google.protobuf.struct_pb2.Struct:
        """Resource specification."""
    @property
    def component_specification(self) -> google.protobuf.struct_pb2.Struct:
        """Component specification."""
    @property
    def openapi_specifications(self) -> google.protobuf.struct_pb2.Struct:
        """OpenAPI specification."""
    def __init__(
        self,
        *,
        resource_specification: google.protobuf.struct_pb2.Struct | None = ...,
        component_specification: google.protobuf.struct_pb2.Struct | None = ...,
        openapi_specifications: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification", "openapi_specifications", b"openapi_specifications", "resource_specification", b"resource_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification", "openapi_specifications", b"openapi_specifications", "resource_specification", b"resource_specification"]) -> None: ...

global___ConnectorSpec = ConnectorSpec

@typing_extensions.final
class ConnectorDefinition(google.protobuf.message.Message):
    """A Connector is a type of pipeline component that queries, processes or sends
    the ingested unstructured data to a service or app. Users need to configure
    their connectors (e.g. by providing an API token to a remote service). A
    ConnectorDefinition describes a certain type of Connector.

    For more information, see
    [Component](https://www.instill.tech/docs/latest/core/concepts/pipeline#pipeline-component)
    in the official documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _View:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConnectorDefinition._View.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIEW_UNSPECIFIED: ConnectorDefinition._View.ValueType  # 0
        """Unspecified, equivalent to BASIC."""
        VIEW_BASIC: ConnectorDefinition._View.ValueType  # 1
        """Default view, only includes basic information (removes the `spec`
        field).
        """
        VIEW_FULL: ConnectorDefinition._View.ValueType  # 2
        """Full representation."""

    class View(_View, metaclass=_ViewEnumTypeWrapper):
        """View defines how a connector definition is presented."""

    VIEW_UNSPECIFIED: ConnectorDefinition.View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: ConnectorDefinition.View.ValueType  # 1
    """Default view, only includes basic information (removes the `spec`
    field).
    """
    VIEW_FULL: ConnectorDefinition.View.ValueType  # 2
    """Full representation."""

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TOMBSTONE_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    VENDOR_ATTRIBUTES_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the connector definition, defined by its ID.
    - Format: `connector-definitions/{id}
    """
    uid: builtins.str
    """Connector definition UUID."""
    id: builtins.str
    """Connector definition resource ID (used in `name` as the last segment). This
    conforms to RFC-1034, which restricts to letters, numbers, and hyphen,
    with the first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    title: builtins.str
    """Connector definition title."""
    documentation_url: builtins.str
    """Connector definition documentation URL."""
    icon: builtins.str
    """Connector definition icon. This is a path that's relative to the root of
    the connector implementation (see `source_url`) and that allows clients
    frontend applications to pull and locate the icons.
    """
    @property
    def spec(self) -> global___ConnectorSpec:
        """Connector definition specification."""
    type: global___ConnectorType.ValueType
    """Connector definition type."""
    tombstone: builtins.bool
    """Connector definition tombstone. If true, this configuration is permanently
    off. Otherwise, the configuration is active.
    """
    public: builtins.bool
    """The public flag determines whether this connector definition is available
    to all workspaces.
    """
    custom: builtins.bool
    """Connector definition custom flag, i.e., whether this is a custom
    connector definition.
    """
    vendor: builtins.str
    """Connector definition vendor name."""
    @property
    def vendor_attributes(self) -> google.protobuf.struct_pb2.Struct:
        """Vendor-specific attributes."""
    source_url: builtins.str
    """Source code URL. This points to the source code where the connector is
    implemented.
    """
    version: builtins.str
    """Connector definition version. This is a string that fulfills the SemVer
    specification (e.g. `1.0.0-beta`).
    """
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vdp.pipeline.v1beta.common_pb2.ComponentTask]:
        """List of tasks that can be executed by the connector."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        documentation_url: builtins.str = ...,
        icon: builtins.str = ...,
        spec: global___ConnectorSpec | None = ...,
        type: global___ConnectorType.ValueType = ...,
        tombstone: builtins.bool = ...,
        public: builtins.bool = ...,
        custom: builtins.bool = ...,
        vendor: builtins.str = ...,
        vendor_attributes: google.protobuf.struct_pb2.Struct | None = ...,
        source_url: builtins.str = ...,
        version: builtins.str = ...,
        tasks: collections.abc.Iterable[vdp.pipeline.v1beta.common_pb2.ComponentTask] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec", "vendor_attributes", b"vendor_attributes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom", b"custom", "documentation_url", b"documentation_url", "icon", b"icon", "id", b"id", "name", b"name", "public", b"public", "source_url", b"source_url", "spec", b"spec", "tasks", b"tasks", "title", b"title", "tombstone", b"tombstone", "type", b"type", "uid", b"uid", "vendor", b"vendor", "vendor_attributes", b"vendor_attributes", "version", b"version"]) -> None: ...

global___ConnectorDefinition = ConnectorDefinition

@typing_extensions.final
class ListConnectorDefinitionsRequest(google.protobuf.message.Message):
    """/////////////////////////////////////////////////////////////////////
    RPC messages
    /////////////////////////////////////////////////////////////////////

    ListConnectorDefinitionsRequest represents a request to list connector
    definitions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connector definitions to return. If this parameter
    is unspecified, at most 10 pipelines will be returned. The cap value for
    this parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___ConnectorDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___ConnectorDefinition.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListConnectorDefinitionsRequest = ListConnectorDefinitionsRequest

@typing_extensions.final
class ListConnectorDefinitionsResponse(google.protobuf.message.Message):
    """ListConnectorDefinitionsResponse contains a list of connector definitions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_DEFINITIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connector_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorDefinition]:
        """A list of connector definition resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of connector definitions."""
    def __init__(
        self,
        *,
        connector_definitions: collections.abc.Iterable[global___ConnectorDefinition] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_definitions", b"connector_definitions", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorDefinitionsResponse = ListConnectorDefinitionsResponse

@typing_extensions.final
class GetConnectorDefinitionRequest(google.protobuf.message.Message):
    """GetConnectorDefinitionRequest represents a request to fetch the details of a
    connector definition.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector definition, which allows its access by ID.
    - Format: `connector-definitions/{id}`.
    """
    view: global___ConnectorDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___ConnectorDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetConnectorDefinitionRequest = GetConnectorDefinitionRequest

@typing_extensions.final
class GetConnectorDefinitionResponse(google.protobuf.message.Message):
    """GetConnectorDefinitionResponse contains the requested connector definition."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def connector_definition(self) -> global___ConnectorDefinition:
        """The connector definition resource."""
    def __init__(
        self,
        *,
        connector_definition: global___ConnectorDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> None: ...

global___GetConnectorDefinitionResponse = GetConnectorDefinitionResponse

@typing_extensions.final
class LookUpConnectorDefinitionAdminRequest(google.protobuf.message.Message):
    """LookUpConnectorDefinitionAdminRequest represents a request by an admin to
    query a connector definition by its UID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """The permalink of the connector definition, which allows its access by UID.
    - Format: `connector-definitions/{uid}`
    """
    view: global___ConnectorDefinition.View.ValueType
    """View allows clients to specify the desired connector definition view in
    the response.
    """
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
        view: global___ConnectorDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "permalink", b"permalink", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___LookUpConnectorDefinitionAdminRequest = LookUpConnectorDefinitionAdminRequest

@typing_extensions.final
class LookUpConnectorDefinitionAdminResponse(google.protobuf.message.Message):
    """LookUpConnectorDefinitionAdminResponse represents a response for a
    connector definition.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def connector_definition(self) -> global___ConnectorDefinition:
        """The requested connector."""
    def __init__(
        self,
        *,
        connector_definition: global___ConnectorDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> None: ...

global___LookUpConnectorDefinitionAdminResponse = LookUpConnectorDefinitionAdminResponse



# pylint: disable=no-member,wrong-import-position,no-name-in-module
import json

import jsonschema

from instill.clients import InstillClient
from instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 import Component
from instill.resources import const
from instill.resources.connector import Connector
from instill.resources.schema import (
    airbyte,
    airbyte_task_write_destination_input,
    helper,
)


class AirbyteAmazonsqsConnector(Connector):
    """Airbyte Amazonsqs Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Amazonsqs,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteAmazonsqsConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteAwsdatalakeConnector(Connector):
    """Airbyte Awsdatalake Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Awsdatalake,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteAwsdatalakeConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteAzureblobstorageConnector(Connector):
    """Airbyte Azureblobstorage Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Azureblobstorage,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config, AirbyteAzureblobstorageConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteBigqueryConnector(Connector):
    """Airbyte Bigquery Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Bigquery,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteBigqueryConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteCassandraConnector(Connector):
    """Airbyte Cassandra Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Cassandra,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteCassandraConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteChromaConnector(Connector):
    """Airbyte Chroma Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Chroma,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteChromaConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteClickhouseConnector(Connector):
    """Airbyte Clickhouse Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Clickhouse,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteClickhouseConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteConvexConnector(Connector):
    """Airbyte Convex Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Convex,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteConvexConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteCsvConnector(Connector):
    """Airbyte Csv Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Csv,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteCsvConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteCumulioConnector(Connector):
    """Airbyte Cumulio Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Cumulio,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteCumulioConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteDatabendConnector(Connector):
    """Airbyte Databend Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Databend,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteDatabendConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteDatabricksConnector(Connector):
    """Airbyte Databricks Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Databricks,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteDatabricksConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteDorisConnector(Connector):
    """Airbyte Doris Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Doris,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteDorisConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteDuckdbConnector(Connector):
    """Airbyte Duckdb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Duckdb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteDuckdbConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteDynamodbConnector(Connector):
    """Airbyte Dynamodb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Dynamodb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteDynamodbConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteE2etestConnector(Connector):
    """Airbyte E2etest Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.E2etest,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteE2etestConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteElasticsearchConnector(Connector):
    """Airbyte Elasticsearch Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Elasticsearch,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config, AirbyteElasticsearchConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteExasolConnector(Connector):
    """Airbyte Exasol Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Exasol,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteExasolConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteFireboltConnector(Connector):
    """Airbyte Firebolt Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Firebolt,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteFireboltConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteFirestoreConnector(Connector):
    """Airbyte Firestore Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Firestore,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteFirestoreConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteGcsConnector(Connector):
    """Airbyte Gcs Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Gcs,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteGcsConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteGooglesheetsConnector(Connector):
    """Airbyte Googlesheets Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Googlesheets,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteGooglesheetsConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteIcebergConnector(Connector):
    """Airbyte Iceberg Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Iceberg,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteIcebergConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteKafkaConnector(Connector):
    """Airbyte Kafka Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Kafka,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteKafkaConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteKeenConnector(Connector):
    """Airbyte Keen Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Keen,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteKeenConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteKinesisConnector(Connector):
    """Airbyte Kinesis Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Kinesis,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteKinesisConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteLangchainConnector(Connector):
    """Airbyte Langchain Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Langchain,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteLangchainConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteLocaljsonConnector(Connector):
    """Airbyte Localjson Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Localjson,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteLocaljsonConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMariadbcolumnstoreConnector(Connector):
    """Airbyte Mariadbcolumnstore Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Mariadbcolumnstore,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config, AirbyteMariadbcolumnstoreConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMeilisearchConnector(Connector):
    """Airbyte Meilisearch Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Meilisearch,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteMeilisearchConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMilvusConnector(Connector):
    """Airbyte Milvus Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Milvus,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteMilvusConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMongodbConnector(Connector):
    """Airbyte Mongodb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Mongodb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteMongodbConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMqttConnector(Connector):
    """Airbyte Mqtt Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Mqtt,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteMqttConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbytMssqlConnector(Connector):
    """Airbyte Mssql Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Mssql,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbytMssqlConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteMysqlConnector(Connector):
    """Airbyte Mysql Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Mysql,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteMysqlConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteOracleConnector(Connector):
    """Airbyte Oracle Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Oracle,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteOracleConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbytePineconeConnector(Connector):
    """Airbyte Pinecone Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Pinecone,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbytePineconeConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbytePostgresConnector(Connector):
    """Airbyte Postgres Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Postgres,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbytePostgresConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbytePubsubConnector(Connector):
    """Airbyte Pubsub Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Pubsub,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbytePubsubConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbytePulsarConnector(Connector):
    """Airbyte Pulsar Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Pulsar,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbytePulsarConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteQdrantConnector(Connector):
    """Airbyte Qdrant Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Qdrant,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteQdrantConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteR2Connector(Connector):
    """Airbyte R2 Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.R2,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteR2Connector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteRabbitmqConnector(Connector):
    """Airbyte Rabbitmq Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Rabbitmq,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteRabbitmqConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteRedisConnector(Connector):
    """Airbyte Redis Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Redis,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteRedisConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteRedpandaConnector(Connector):
    """Airbyte Redpanda Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Redpanda,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteRedpandaConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteRedshiftConnector(Connector):
    """Airbyte Redshift Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Redshift,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteRedshiftConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteRocksetConnector(Connector):
    """Airbyte Rockset Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Rockset,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteRocksetConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteS3glueConnector(Connector):
    """Airbyte S3glue Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.S3glue,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteS3glueConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteS3Connector(Connector):
    """Airbyte S3 Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.S3,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteS3Connector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteScyllaConnector(Connector):
    """Airbyte Scylla Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Scylla,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteScyllaConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteSelectdbConnector(Connector):
    """Airbyte Selectdb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Selectdb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteSelectdbConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteSftpjsonConnector(Connector):
    """Airbyte Sftpjson Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Sftpjson,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteSftpjsonConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteSnowflakeConnector(Connector):
    """Airbyte Snowflake Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Snowflake,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteSnowflakeConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteSqliteConnector(Connector):
    """Airbyte Sqlite Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Sqlite,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteSqliteConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteStarburstgalaxyConnector(Connector):
    """Airbyte Starburstgalaxy Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Starburstgalaxy,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config, AirbyteStarburstgalaxyConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteTeradataConnector(Connector):
    """Airbyte Teradata Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Teradata,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteTeradataConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteTidbConnector(Connector):
    """Airbyte Tidb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Tidb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteTidbConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteTimeplusConnector(Connector):
    """Airbyte Timeplus Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Timeplus,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteTimeplusConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteTypesenseConnector(Connector):
    """Airbyte Typesense Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Typesense,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteTypesenseConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteVerticaConnector(Connector):
    """Airbyte Vertica Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Vertica,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteVerticaConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteWeaviateConnector(Connector):
    """Airbyte Weaviate Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Weaviate,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteWeaviateConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteXataConnector(Connector):
    """Airbyte Xata Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Xata,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, AirbyteXataConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteYugabytedbConnector(Connector):
    """Airbyte Yugabytedb Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Yugabytedb,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, AirbyteYugabytedbConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class AirbyteAirbytedevmatecloudConnector(Connector):
    """Airbyte Airbytedevmatecloud Connector"""

    with open(f"{const.SPEC_PATH}/airbyte_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: airbyte.Airbytedevmatecloud,
    ) -> None:
        definition = "connector-definitions/airbyte-destination"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config, AirbyteAirbytedevmatecloudConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: airbyte_task_write_destination_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)



# generated by datamodel-codegen:
#   filename:  huggingface_task_sentence_similarity_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Output:
    scores: List[float]



# generated by datamodel-codegen:
#   filename:  redis_task_chat_message_write_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, Optional


@dataclass
class Input:
    content: str
    role: str
    session_id: str
    metadata: Optional[Dict[str, Any]] = None



class ModelPathException(Exception):
    def __str__(self) -> str:
        return "model path is not valid"


class ModelVramException(Exception):
    def __str__(self) -> str:
        return "model projected vram usage is more than the GPU can handle"



# generated by datamodel-codegen:
#   filename:  huggingface_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class HuggingFaceConnectorSpec:
    api_key: str
    base_url: str
    is_custom_endpoint: bool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import grpc.aio
import model.model.v1alpha.model_definition_pb2
import model.model.v1alpha.model_pb2
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ModelPublicServiceStub:
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LivenessRequest,
        model.model.v1alpha.model_pb2.LivenessResponse,
    ]
    """Check if the model server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ReadinessRequest,
        model.model.v1alpha.model_pb2.ReadinessResponse,
    ]
    """Check if the model server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    ListModelDefinitions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse,
    ]
    """List model definitions

    Returns a paginated list of model definitions.
    """
    GetModelDefinition: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse,
    ]
    """Get a model definition

    Returns the details of a model definition.
    """
    ListModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelsRequest,
        model.model.v1alpha.model_pb2.ListModelsResponse,
    ]
    """List models

    Returns a paginated list of models.
    """
    LookUpModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LookUpModelRequest,
        model.model.v1alpha.model_pb2.LookUpModelResponse,
    ]
    """Get a model by UID

    Returns the details of a model by a permalink defined by the resource UID.
    """
    ListUserModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelsRequest,
        model.model.v1alpha.model_pb2.ListUserModelsResponse,
    ]
    """List user models

    Returns a paginated list of models that belong to the specified user. The
    parent user may be different from the authenticated user, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelRequest,
        model.model.v1alpha.model_pb2.CreateUserModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a user. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    CreateUserModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadResponse,
    ]
    """Upload model binary

    Creates a new model by upploading its binary content.
    """
    GetUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelRequest,
        model.model.v1alpha.model_pb2.GetUserModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent user.
    """
    UpdateUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        model.model.v1alpha.model_pb2.UpdateUserModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent user and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    RenameUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameUserModelRequest,
        model.model.v1alpha.model_pb2.RenameUserModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    PublishUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.PublishUserModelRequest,
        model.model.v1alpha.model_pb2.PublishUserModelResponse,
    ]
    """Publish a model

    Updates the visibility in a model to PUBLIC. The model is accessed by its
    resource name, defined by the model ID and its parent user.
    """
    UnpublishUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UnpublishUserModelRequest,
        model.model.v1alpha.model_pb2.UnpublishUserModelResponse,
    ]
    """Unpublish a model

    Updates the visibility in a model to PRIVATE. The model is accessed by its
    resource name, defined by the model ID and its parent user.
    """
    DeployUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeployUserModelRequest,
        model.model.v1alpha.model_pb2.DeployUserModelResponse,
    ]
    """Deploy a model

    Transitions the model into an ONLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent user.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the deployment might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    UndeployUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UndeployUserModelRequest,
        model.model.v1alpha.model_pb2.UndeployUserModelResponse,
    ]
    """Undeploy a model

    Transitions the model into an OFFLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent user.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the teardown might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    GetUserModelCard: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelCardRequest,
        model.model.v1alpha.model_pb2.GetUserModelCardResponse,
    ]
    """Get a model card

    Returns the README file that accompanies a model, describing it and
    enhancing it with metadata. The model is accessed by its resource name.
    """
    WatchUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserModelRequest,
        model.model.v1alpha.model_pb2.WatchUserModelResponse,
    ]
    """Watch the state of a model

    Returns the state of a model. The deploy / undeploy actions take some
    time, during which a model will be in an UNSPECIFIED state. This endpoint
    allows clients to track the state and progress of the model.
    """
    TriggerUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerUserModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    ListOrganizationModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelsResponse,
    ]
    """List organization models

    Returns a paginated list of models that belong to the specified organization. The
    parent organization may be different from the authenticated organization, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of an organization. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    CreateOrganizationModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadResponse,
    ]
    """Upload model binary

    Creates a new model by upploading its binary content.
    """
    GetOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent organization.
    """
    UpdateOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent organization and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    RenameOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        model.model.v1alpha.model_pb2.RenameOrganizationModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    PublishOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.PublishOrganizationModelRequest,
        model.model.v1alpha.model_pb2.PublishOrganizationModelResponse,
    ]
    """Publish a model

    Updates the visibility in a model to PUBLIC. The model is accessed by its
    resource name, defined by the model ID and its parent organization.
    """
    UnpublishOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UnpublishOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UnpublishOrganizationModelResponse,
    ]
    """Unpublish a model

    Updates the visibility in a model to PRIVATE. The model is accessed by its
    resource name, defined by the model ID and its parent organization.
    """
    DeployOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeployOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeployOrganizationModelResponse,
    ]
    """Deploy a model

    Transitions the model into an ONLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent organization.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the deployment might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    UndeployOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UndeployOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UndeployOrganizationModelResponse,
    ]
    """Undeploy a model

    Transitions the model into an OFFLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent organization.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the teardown might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    GetOrganizationModelCard: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelCardRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelCardResponse,
    ]
    """Get a model card

    Returns the README file that accompanies a model, describing it and
    enhancing it with metadata. The model is accessed by its resource name.
    """
    WatchOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationModelResponse,
    ]
    """Watch the state of a model

    Returns the state of a model. The deploy / undeploy actions take some
    time, during which a model will be in an UNSPECIFIED state. This endpoint
    allows clients to track the state and progress of the model.
    """
    TriggerOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    GetModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetModelOperationRequest,
        model.model.v1alpha.model_pb2.GetModelOperationResponse,
    ]
    """Get the details of a long-running operation

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as deployment.
    """

class ModelPublicServiceAsyncStub:
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LivenessRequest,
        model.model.v1alpha.model_pb2.LivenessResponse,
    ]
    """Check if the model server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ReadinessRequest,
        model.model.v1alpha.model_pb2.ReadinessResponse,
    ]
    """Check if the model server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    ListModelDefinitions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse,
    ]
    """List model definitions

    Returns a paginated list of model definitions.
    """
    GetModelDefinition: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse,
    ]
    """Get a model definition

    Returns the details of a model definition.
    """
    ListModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelsRequest,
        model.model.v1alpha.model_pb2.ListModelsResponse,
    ]
    """List models

    Returns a paginated list of models.
    """
    LookUpModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LookUpModelRequest,
        model.model.v1alpha.model_pb2.LookUpModelResponse,
    ]
    """Get a model by UID

    Returns the details of a model by a permalink defined by the resource UID.
    """
    ListUserModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelsRequest,
        model.model.v1alpha.model_pb2.ListUserModelsResponse,
    ]
    """List user models

    Returns a paginated list of models that belong to the specified user. The
    parent user may be different from the authenticated user, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelRequest,
        model.model.v1alpha.model_pb2.CreateUserModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a user. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    CreateUserModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadResponse,
    ]
    """Upload model binary

    Creates a new model by upploading its binary content.
    """
    GetUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelRequest,
        model.model.v1alpha.model_pb2.GetUserModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent user.
    """
    UpdateUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        model.model.v1alpha.model_pb2.UpdateUserModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent user and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    RenameUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameUserModelRequest,
        model.model.v1alpha.model_pb2.RenameUserModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    PublishUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.PublishUserModelRequest,
        model.model.v1alpha.model_pb2.PublishUserModelResponse,
    ]
    """Publish a model

    Updates the visibility in a model to PUBLIC. The model is accessed by its
    resource name, defined by the model ID and its parent user.
    """
    UnpublishUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UnpublishUserModelRequest,
        model.model.v1alpha.model_pb2.UnpublishUserModelResponse,
    ]
    """Unpublish a model

    Updates the visibility in a model to PRIVATE. The model is accessed by its
    resource name, defined by the model ID and its parent user.
    """
    DeployUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeployUserModelRequest,
        model.model.v1alpha.model_pb2.DeployUserModelResponse,
    ]
    """Deploy a model

    Transitions the model into an ONLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent user.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the deployment might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    UndeployUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UndeployUserModelRequest,
        model.model.v1alpha.model_pb2.UndeployUserModelResponse,
    ]
    """Undeploy a model

    Transitions the model into an OFFLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent user.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the teardown might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    GetUserModelCard: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelCardRequest,
        model.model.v1alpha.model_pb2.GetUserModelCardResponse,
    ]
    """Get a model card

    Returns the README file that accompanies a model, describing it and
    enhancing it with metadata. The model is accessed by its resource name.
    """
    WatchUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserModelRequest,
        model.model.v1alpha.model_pb2.WatchUserModelResponse,
    ]
    """Watch the state of a model

    Returns the state of a model. The deploy / undeploy actions take some
    time, during which a model will be in an UNSPECIFIED state. This endpoint
    allows clients to track the state and progress of the model.
    """
    TriggerUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerUserModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    ListOrganizationModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelsResponse,
    ]
    """List organization models

    Returns a paginated list of models that belong to the specified organization. The
    parent organization may be different from the authenticated organization, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of an organization. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    CreateOrganizationModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadResponse,
    ]
    """Upload model binary

    Creates a new model by upploading its binary content.
    """
    GetOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent organization.
    """
    UpdateOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent organization and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    RenameOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        model.model.v1alpha.model_pb2.RenameOrganizationModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    PublishOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.PublishOrganizationModelRequest,
        model.model.v1alpha.model_pb2.PublishOrganizationModelResponse,
    ]
    """Publish a model

    Updates the visibility in a model to PUBLIC. The model is accessed by its
    resource name, defined by the model ID and its parent organization.
    """
    UnpublishOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UnpublishOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UnpublishOrganizationModelResponse,
    ]
    """Unpublish a model

    Updates the visibility in a model to PRIVATE. The model is accessed by its
    resource name, defined by the model ID and its parent organization.
    """
    DeployOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeployOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeployOrganizationModelResponse,
    ]
    """Deploy a model

    Transitions the model into an ONLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent organization.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the deployment might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    UndeployOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UndeployOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UndeployOrganizationModelResponse,
    ]
    """Undeploy a model

    Transitions the model into an OFFLINE state. The model is accessed by its
    resource name, defined by the model ID and its parent organization.

    While this operation is being performed, the state of the model will
    transition to UNSPECIFIED. As completing the teardown might take time,
    the server will not wait to complete the operation to return a response.
    The state of the model can be used to track the completion of the
    operation. This can be done by using the `watch` operation on the model.
    """
    GetOrganizationModelCard: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelCardRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelCardResponse,
    ]
    """Get a model card

    Returns the README file that accompanies a model, describing it and
    enhancing it with metadata. The model is accessed by its resource name.
    """
    WatchOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationModelResponse,
    ]
    """Watch the state of a model

    Returns the state of a model. The deploy / undeploy actions take some
    time, during which a model will be in an UNSPECIFIED state. This endpoint
    allows clients to track the state and progress of the model.
    """
    TriggerOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    GetModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetModelOperationRequest,
        model.model.v1alpha.model_pb2.GetModelOperationResponse,
    ]
    """Get the details of a long-running operation

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as deployment.
    """

class ModelPublicServiceServicer(metaclass=abc.ABCMeta):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: model.model.v1alpha.model_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.LivenessResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.LivenessResponse]]:
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: model.model.v1alpha.model_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ReadinessResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ReadinessResponse]]:
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def ListModelDefinitions(
        self,
        request: model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse]]:
        """List model definitions

        Returns a paginated list of model definitions.
        """
    @abc.abstractmethod
    def GetModelDefinition(
        self,
        request: model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse, collections.abc.Awaitable[model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse]]:
        """Get a model definition

        Returns the details of a model definition.
        """
    @abc.abstractmethod
    def ListModels(
        self,
        request: model.model.v1alpha.model_pb2.ListModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListModelsResponse]]:
        """List models

        Returns a paginated list of models.
        """
    @abc.abstractmethod
    def LookUpModel(
        self,
        request: model.model.v1alpha.model_pb2.LookUpModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.LookUpModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.LookUpModelResponse]]:
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
    @abc.abstractmethod
    def ListUserModels(
        self,
        request: model.model.v1alpha.model_pb2.ListUserModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListUserModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListUserModelsResponse]]:
        """List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
    @abc.abstractmethod
    def CreateUserModel(
        self,
        request: model.model.v1alpha.model_pb2.CreateUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateUserModelResponse]]:
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
    @abc.abstractmethod
    def CreateUserModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateUserModelBinaryFileUploadResponse]]:
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
    @abc.abstractmethod
    def GetUserModel(
        self,
        request: model.model.v1alpha.model_pb2.GetUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetUserModelResponse]]:
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
    @abc.abstractmethod
    def UpdateUserModel(
        self,
        request: model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UpdateUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UpdateUserModelResponse]]:
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteUserModel(
        self,
        request: model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteUserModelResponse]]:
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
    @abc.abstractmethod
    def RenameUserModel(
        self,
        request: model.model.v1alpha.model_pb2.RenameUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.RenameUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.RenameUserModelResponse]]:
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
    @abc.abstractmethod
    def PublishUserModel(
        self,
        request: model.model.v1alpha.model_pb2.PublishUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.PublishUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.PublishUserModelResponse]]:
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
    @abc.abstractmethod
    def UnpublishUserModel(
        self,
        request: model.model.v1alpha.model_pb2.UnpublishUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UnpublishUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UnpublishUserModelResponse]]:
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
    @abc.abstractmethod
    def DeployUserModel(
        self,
        request: model.model.v1alpha.model_pb2.DeployUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeployUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeployUserModelResponse]]:
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
    @abc.abstractmethod
    def UndeployUserModel(
        self,
        request: model.model.v1alpha.model_pb2.UndeployUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UndeployUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UndeployUserModelResponse]]:
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
    @abc.abstractmethod
    def GetUserModelCard(
        self,
        request: model.model.v1alpha.model_pb2.GetUserModelCardRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetUserModelCardResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetUserModelCardResponse]]:
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
    @abc.abstractmethod
    def WatchUserModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchUserModelResponse]]:
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
    @abc.abstractmethod
    def TriggerUserModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerUserModelResponse]]:
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerUserModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
    @abc.abstractmethod
    def ListOrganizationModels(
        self,
        request: model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListOrganizationModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListOrganizationModelsResponse]]:
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
    @abc.abstractmethod
    def CreateOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateOrganizationModelResponse]]:
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
    @abc.abstractmethod
    def CreateOrganizationModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateOrganizationModelBinaryFileUploadResponse]]:
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
    @abc.abstractmethod
    def GetOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetOrganizationModelResponse]]:
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
    @abc.abstractmethod
    def UpdateOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse]]:
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse]]:
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
    @abc.abstractmethod
    def RenameOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.RenameOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.RenameOrganizationModelResponse]]:
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
    @abc.abstractmethod
    def PublishOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.PublishOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.PublishOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.PublishOrganizationModelResponse]]:
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
    @abc.abstractmethod
    def UnpublishOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.UnpublishOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UnpublishOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UnpublishOrganizationModelResponse]]:
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
    @abc.abstractmethod
    def DeployOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.DeployOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeployOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeployOrganizationModelResponse]]:
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
    @abc.abstractmethod
    def UndeployOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.UndeployOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UndeployOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UndeployOrganizationModelResponse]]:
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
    @abc.abstractmethod
    def GetOrganizationModelCard(
        self,
        request: model.model.v1alpha.model_pb2.GetOrganizationModelCardRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetOrganizationModelCardResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetOrganizationModelCardResponse]]:
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
    @abc.abstractmethod
    def WatchOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchOrganizationModelResponse]]:
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
    @abc.abstractmethod
    def TriggerOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse]]:
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerOrganizationModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
    @abc.abstractmethod
    def GetModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetModelOperationResponse]]:
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """

def add_ModelPublicServiceServicer_to_server(servicer: ModelPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
